.panel-item{height:100%;padding:10px}.panel-item-checkbox{position:absolute;left:0px;top:0px}.panel-item-details{padding-left:0!important;padding-right:0!important}.hiresicon{margin-top:5px;margin-left:-10px;filter:invert(100%)}.hiresicondark{margin-top:5px;margin-left:-10px}
