import{l as d,J as v,r as i,B as n,O as o,U as y,b as m,o as E,af as s,q as I,v as A}from"./index-e9211ef1.js";import{_ as D}from"./ItemsListing.vue_vue_type_script_setup_true_lang-436cf3d3.js";import"./ListviewItem-b7a4258b.js";import"./MediaItemThumb.vue_vue_type_style_index_0_lang-278977b5.js";import"./VMenu-bc0cce60.js";import"./VDivider-336c24cd.js";import"./VBtn-68784d55.js";import"./VListItem-230d1393.js";import"./Container-349a0ac0.js";/* empty css              */import"./VDialog-5f240a62.js";import"./VCard-138864fc.js";import"./VToolbar-daf2b89f.js";import"./VSelect-04a129eb.js";/* empty css                             */import"./PanelviewItem.vue_vue_type_style_index_0_lang-fefd2afe.js";import"./Alert-55091fd0.js";import"./VSpacer-bdf2f653.js";import"./VBadge-9fa94f29.js";import"./VRow-e8f3e51e.js";const F=d({__name:"LibraryArtists",setup(M){const{t:p}=v(),l=i([]),r=i(!1),u=async function(t,a,e,c,_=!0,f=!0){const b=_||void 0;return r.value=!1,await o.getLibraryArtists(b,c,a,t,e,f)};return n.topBarContextMenuItems=[{label:"sync_now",labelArgs:[p("artists")],action:()=>{o.startSync([y.ARTIST])},icon:"mdi-sync"}],m(()=>{n.topBarContextMenuItems=[]}),E(()=>{const t=o.subscribe_multi([s.MEDIA_ITEM_ADDED,s.MEDIA_ITEM_UPDATED,s.MEDIA_ITEM_DELETED],a=>{var e;(e=a.object_id)!=null&&e.startsWith("library://artist")&&(r.value=!0)});m(t)}),(t,a)=>(I(),A(D,{itemtype:"artists",items:l.value,"show-provider":!1,"show-favorites-only-filter":!0,"load-data":u,"show-album-artists-only-filter":!0,"update-available":r.value},null,8,["items","update-available"]))}});export{F as default};
