import{l as C,I as b,r as h,o as k,O as t,P as V,a9 as x,q as i,v as c,x as o,j as n,y,z as M,A as a,F as w,Q as B,L as m,N as p,K as N,M as L}from"./index-e9211ef1.js";import{C as u,L as D,a as I}from"./Container-349a0ac0.js";import{V as $}from"./VToolbar-daf2b89f.js";import{V as A}from"./VDivider-336c24cd.js";import{a as T}from"./VCard-138864fc.js";import{V as z}from"./VBtn-68784d55.js";import"./VMenu-bc0cce60.js";import"./VListItem-230d1393.js";/* empty css              */const F={class:"line-clamp-1"},j={class:"line-clamp-1"},U=C({__name:"CoreConfigs",setup(q){const f=b(),r=h([]);console.log(r);const l=function(s){f.push(`/settings/editcore/${s}`)},_=function(s){window.open(s,"_blank")};return k(async()=>{r.value=await t.getCoreConfigs()}),(s,E)=>{const g=V("Button"),v=x("hold");return i(),c(u,null,{default:o(()=>[n(T,{style:{"margin-bottom":"10px"}},{default:o(()=>[n($,{color:"transparent",title:s.$t("settings.core_modules"),style:{height:"55px"}},null,8,["title"]),n(A),n(u,null,{default:o(()=>[(i(!0),y(w,null,M(r.value.sort((e,d)=>a(t).providerManifests[e.domain].name.localeCompare(a(t).providerManifests[d.domain].name)),e=>B((i(),c(D,{key:e.domain,class:"list-item-main",link:"",onClick:d=>l(e.domain),"context-menu-items":[{label:"settings.configure",labelArgs:[],action:()=>{l(e.domain)},icon:"mdi-cog"},{label:"settings.documentation",labelArgs:[],action:()=>{_(a(t).providerManifests[e.domain].documentation)},icon:"mdi-bookshelf",disabled:!a(t).providerManifests[e.domain].documentation}]},{prepend:o(()=>[n(I,{domain:e.domain,size:40,class:"listitem-media-thumb",style:{"margin-left":"10px"}},null,8,["domain"])]),title:o(()=>[m("div",F,p(a(t).providerManifests[e.domain].name),1)]),subtitle:o(()=>[m("div",j,p(a(t).providerManifests[e.domain].description),1)]),append:o(()=>[e.last_error?(i(),c(g,{key:0,icon:"",title:e.last_error},{default:o(()=>[n(z,{color:"red"},{default:o(()=>[N(" mdi-alert-circle ")]),_:1})]),_:2},1032,["title"])):L("",!0)]),_:2},1032,["onClick","context-menu-items"])),[[v,()=>{l(e.domain)}]])),128))]),_:1})]),_:1})]),_:1})}}});export{U as default};
