import{_ as f,f as u}from"./ItemsListing.vue_vue_type_script_setup_true_lang-436cf3d3.js";import{_ as v}from"./InfoHeader.vue_vue_type_style_index_0_lang-36a95710.js";import{l as _,r as h,w,q as y,y as I,j as r,O as a}from"./index-e9211ef1.js";import"./ListviewItem-b7a4258b.js";import"./MediaItemThumb.vue_vue_type_style_index_0_lang-278977b5.js";import"./VMenu-bc0cce60.js";import"./VDivider-336c24cd.js";import"./VBtn-68784d55.js";import"./VListItem-230d1393.js";import"./Container-349a0ac0.js";/* empty css              */import"./VDialog-5f240a62.js";import"./VCard-138864fc.js";import"./VToolbar-daf2b89f.js";import"./VSelect-04a129eb.js";/* empty css                             */import"./PanelviewItem.vue_vue_type_style_index_0_lang-fefd2afe.js";import"./Alert-55091fd0.js";import"./VSpacer-bdf2f653.js";import"./VBadge-9fa94f29.js";import"./VRow-e8f3e51e.js";import"./layout-4499d5bc.js";const M=_({__name:"RadioDetails",props:{itemId:{},provider:{}},setup(s){const e=s,o=h(),m=async function(){o.value=await a.getRadio(e.itemId,e.provider)};w(()=>e.itemId,t=>{t&&m()},{immediate:!0});const p=async function(t,i,n,l,d=!0){const c=await a.getRadioVersions(e.itemId,e.provider);return u(c,t,i,n,l,d)};return(t,i)=>(y(),I("section",null,[r(v,{item:o.value},null,8,["item"]),r(f,{itemtype:"radioversions","parent-item":o.value,"show-provider":!0,"show-favorites-only-filter":!1,"show-library":!1,"show-radio-number":!1,"show-duration":!1,"load-data":p,"sort-keys":["provider","sort_name"],title:t.$t("other_versions"),checksum:t.provider+t.itemId},null,8,["parent-item","title","checksum"])]))}});export{M as default};
