import{c,P as C,q as i,v as d,V as M,z as y,x as l,Y as k,y as p,j as u,k as $,F as V,M as I,l as L,O as r,A as o,X as f,p as P,g as b,u as B}from"./index-e9211ef1.js";import{b as T,V as w}from"./VMenu-bc0cce60.js";import{l as A,V as _,a as H,d as D,i as F}from"./VBtn-68784d55.js";import{a as S,V as N}from"./VListItem-230d1393.js";/* empty css              */const h=(t,a)=>{const e=t.__vccOpts||t;for(const[n,m]of a)e[n]=m;return e},O={props:{contextMenuItems:{type:Array,default:[]}},setup(t,a){const e=c(()=>({}));return{listItemProps:c(()=>({...e.value,...a.attrs}))}}};const R={key:0,class:"contextmenubtn"};function j(t,a,e,n,m,z){const g=C("ListItem",!0);return i(),d(N,$(n.listItemProps,{class:"list-item-main",onInput:a[0]||(a[0]=s=>t.$emit("input",s))}),M({_:2},[y(t.$slots,(s,v)=>({name:v,fn:l(()=>[k(t.$slots,v)])})),t.$slots.append?{name:"append",fn:l(()=>[k(t.$slots,"append"),e.contextMenuItems.length>0?(i(),p("div",R,[u(T,{location:"bottom end"},{activator:l(({props:s})=>[u(A,$({variant:"plain",ripple:"",icon:"mdi-dots-vertical"},s),null,16)]),default:l(()=>[u(w,null,{default:l(()=>[(i(!0),p(V,null,y(e.contextMenuItems.filter(s=>s.hide!=!0),(s,v)=>(i(),d(g,{key:v,title:t.$t(s.label,s.labelArgs),onClick:J=>s.action?s.action():"",disabled:s.disabled==!0},{prepend:l(()=>[u(S,{icon:s.icon},null,8,["icon"])]),_:2},1032,["title","onClick","disabled"]))),128))]),_:1})]),_:1})])):I("",!0)]),key:"0"}:void 0]),1040)}const ee=h(O,[["render",j]]),q=["innerHTML","title"],E=["innerHTML","title"],te=L({__name:"ProviderIcon",props:{domain:{},size:{},dark:{type:Boolean}},setup(t){const a=t,e=c(()=>a.domain in r.providers?r.providers[a.domain].domain:a.domain);return(n,m)=>(i(),p("div",{style:f(`width:${n.size}px;margin-left:10px;margin-right:10px`)},[e.value=="library"?(i(),d(_,{key:0,size:n.size,icon:"mdi-bookshelf",title:n.$t("library")},null,8,["size","title"])):n.$vuetify.theme.current.dark&&o(r).providerManifests[e.value].icon_svg_dark?(i(),p("div",{key:1,style:f(`width: ${n.size}px`),innerHTML:o(r).providerManifests[e.value].icon_svg_dark,title:o(r).providerManifests[e.value].name},null,12,q)):o(r).providerManifests[e.value].icon_svg?(i(),p("div",{key:2,style:f(`width: ${n.size}px;height: ${n.size}px`),innerHTML:o(r).providerManifests[e.value].icon_svg,title:o(r).providerManifests[e.value].name},null,12,E)):o(r).providerManifests[e.value].icon?(i(),d(_,{key:3,size:n.size,icon:"mdi-"+o(r).providerManifests[e.value].icon,title:o(r).providerManifests[e.value].name,dark:n.$vuetify.theme.current.dark},null,8,["size","icon","title","dark"])):(i(),d(_,{key:4,size:n.size,dark:n.$vuetify.theme.current.dark,icon:"mdi-playlist-play"},null,8,["size","dark"]))],4))}}),X={setup(t,a){const e=c(()=>({}));return{containerProps:c(()=>({...e.value,...a.attrs}))}}};const Y=P({fluid:{type:Boolean,default:!1},...H(),...D()},"VContainer"),x=b()({name:"VContainer",props:Y(),setup(t,a){let{slots:e}=a;const{rtlClasses:n}=B();return F(()=>u(t.tag,{class:["v-container",{"v-container--fluid":t.fluid},n.value,t.class],style:t.style},e)),{}}});function G(t,a,e,n,m,z){return i(),d(x,$(n.containerProps,{class:"container",fluid:""}),M({_:2},[y(t.$slots,(g,s)=>({name:s,fn:l(()=>[k(t.$slots,s)])}))]),1040)}const ne=h(X,[["render",G]]);export{ne as C,ee as L,h as _,te as a};
