.list-item-main{border-radius:4px!important;padding:7px!important}.list-item-main>div.v-list-item__append{display:flex;justify-content:end;vertical-align:middle;align-items:center;padding:0}.list-item-main>div.v-list-item__prepend>.v-icon{margin-inline-end:5px!important}.list-item-main>div.v-list-item__append>.v-icon{margin-inline-start:5px!important}.list-item-main>div.v-list-item__prepend>button{margin-inline-end:5px!important}.list-item-main>div.v-list-item__append>button{margin-inline-start:5px!important}.list-item-main>div.v-list-item__content>div{padding-left:10px;padding-right:10px}.contextmenubtn{width:25px;margin-right:-13px}.container{padding:20px}@media (min-width: 1920px){.container{max-width:unset!important}}@media (min-width: 1280px){.container{max-width:unset!important}}@media (min-width: 960px){.container{max-width:unset!important}}
