import{a as y,i as f,E as h,x as k,m as q,G,b as J,J as K,o as N,p as Q,c as $,K as z,d as U,q as W,R as X,u as Y,v as Z,F as ee,H as ae,f as te,I as ne,r as de,s as ie,g as se,O as le,L as ce,w as re}from"./VBtn-68784d55.js";import{g as b,i as ue,j as n,p as P,av as u,m as ve,d as oe,c as V,Q as me,a9 as ge}from"./index-e9211ef1.js";import{e as p,a as A,b as ke}from"./VListItem-230d1393.js";const ye=b()({name:"VCardActions",props:y(),setup(e,i){let{slots:t}=i;return ue({VBtn:{variant:"text"}}),f(()=>{var a;return n("div",{class:["v-card-actions",e.class],style:e.style},[(a=t.default)==null?void 0:a.call(t)])}),{}}}),fe=p("v-card-subtitle"),be=p("v-card-title"),pe=P({appendAvatar:String,appendIcon:u,prependAvatar:String,prependIcon:u,subtitle:String,title:String,...y(),...h()},"VCardItem"),Ce=b()({name:"VCardItem",props:pe(),setup(e,i){let{slots:t}=i;return f(()=>{var l;const a=!!(e.prependAvatar||e.prependIcon),v=!!(a||t.prepend),s=!!(e.appendAvatar||e.appendIcon),o=!!(s||t.append),m=!!(e.title||t.title),g=!!(e.subtitle||t.subtitle);return n("div",{class:["v-card-item",e.class],style:e.style},[v&&n("div",{key:"prepend",class:"v-card-item__prepend"},[t.prepend?n(k,{key:"prepend-defaults",disabled:!a,defaults:{VAvatar:{density:e.density,icon:e.prependIcon,image:e.prependAvatar}}},t.prepend):a&&n(A,{key:"prepend-avatar",density:e.density,icon:e.prependIcon,image:e.prependAvatar},null)]),n("div",{class:"v-card-item__content"},[m&&n(be,{key:"title"},{default:()=>{var d;return[((d=t.title)==null?void 0:d.call(t))??e.title]}}),g&&n(fe,{key:"subtitle"},{default:()=>{var d;return[((d=t.subtitle)==null?void 0:d.call(t))??e.subtitle]}}),(l=t.default)==null?void 0:l.call(t)]),o&&n("div",{key:"append",class:"v-card-item__append"},[t.append?n(k,{key:"append-defaults",disabled:!s,defaults:{VAvatar:{density:e.density,icon:e.appendIcon,image:e.appendAvatar}}},t.append):s&&n(A,{key:"append-avatar",density:e.density,icon:e.appendIcon,image:e.appendAvatar},null)])])}),{}}}),Ie=p("v-card-text"),Ve=P({appendAvatar:String,appendIcon:u,disabled:Boolean,flat:Boolean,hover:Boolean,image:String,link:{type:Boolean,default:void 0},prependAvatar:String,prependIcon:u,ripple:{type:[Boolean,Object],default:!0},subtitle:String,text:String,title:String,...q(),...y(),...h(),...G(),...J(),...K(),...N(),...Q(),...$(),...z(),...U(),...ve(),...W({variant:"elevated"})},"VCard"),Se=b()({name:"VCard",directives:{Ripple:X},props:Ve(),setup(e,i){let{attrs:t,slots:a}=i;const{themeClasses:v}=oe(e),{borderClasses:s}=Y(e),{colorClasses:o,colorStyles:m,variantClasses:g}=Z(e),{densityClasses:l}=ee(e),{dimensionStyles:d}=ae(e),{elevationClasses:S}=te(e),{loaderClasses:x}=ne(e),{locationStyles:L}=de(e),{positionClasses:T}=ie(e),{roundedClasses:B}=se(e),c=le(e,t),D=V(()=>e.link!==!1&&c.isLink.value),r=V(()=>!e.disabled&&e.link!==!1&&(e.link||c.isClickable.value));return f(()=>{const _=D.value?"a":e.tag,R=!!(a.title||e.title),E=!!(a.subtitle||e.subtitle),F=R||E,O=!!(a.append||e.appendAvatar||e.appendIcon),j=!!(a.prepend||e.prependAvatar||e.prependIcon),w=!!(a.image||e.image),H=F||j||O,M=!!(a.text||e.text);return me(n(_,{class:["v-card",{"v-card--disabled":e.disabled,"v-card--flat":e.flat,"v-card--hover":e.hover&&!(e.disabled||e.flat),"v-card--link":r.value},v.value,s.value,o.value,l.value,S.value,x.value,T.value,B.value,g.value,e.class],style:[m.value,d.value,L.value,e.style],href:c.href.value,onClick:r.value&&c.navigate,tabindex:e.disabled?-1:void 0},{default:()=>{var C;return[w&&n("div",{key:"image",class:"v-card__image"},[a.image?n(k,{key:"image-defaults",disabled:!e.image,defaults:{VImg:{cover:!0,src:e.image}}},a.image):n(ke,{key:"image-img",cover:!0,src:e.image},null)]),n(ce,{name:"v-card",active:!!e.loading,color:typeof e.loading=="boolean"?void 0:e.loading},{default:a.loader}),H&&n(Ce,{key:"item",prependAvatar:e.prependAvatar,prependIcon:e.prependIcon,title:e.title,subtitle:e.subtitle,appendAvatar:e.appendAvatar,appendIcon:e.appendIcon},{default:a.item,prepend:a.prepend,title:a.title,subtitle:a.subtitle,append:a.append}),M&&n(Ie,{key:"text"},{default:()=>{var I;return[((I=a.text)==null?void 0:I.call(a))??e.text]}}),(C=a.default)==null?void 0:C.call(a),a.actions&&n(ye,null,{default:a.actions}),re(r.value,"v-card")]}}),[[ge("ripple"),r.value&&e.ripple]])}),{}}});export{fe as V,Se as a,be as b,Ie as c,ye as d};
