import{V as r,a as m}from"./VRow-e8f3e51e.js";import{a as c}from"./VCard-138864fc.js";import{V as p}from"./VListItem-230d1393.js";import{l as d,V as u}from"./VBtn-68784d55.js";import{l as _,r as f,q as i,y as o,L as l,j as a,x as t,F as h,z as b,v as g,N as V}from"./index-e9211ef1.js";/* empty css              */const v={style:{"margin-left":"10px","margin-right":"10px","margin-top":"10px","margin-bottom":"10px"}},y={class:"mb-4"},F=_({__name:"HomeView",setup(x){const n=f([{label:"artists",icon:"mdi-account-music",path:"/artists"},{label:"albums",icon:"mdi-album",path:"/albums"},{label:"tracks",icon:"mdi-file-music",path:"/tracks"},{label:"radios",icon:"mdi-radio",path:"/radios"},{label:"playlists",icon:"mdi-playlist-music",path:"/playlists"},{label:"browse",icon:"mdi-folder",path:"/browse"}]);return(s,k)=>(i(),o("div",null,[l("div",v,[l("div",null,[a(r,{dense:"","align-content":"start",align:"start"},{default:t(()=>[(i(!0),o(h,null,b(n.value,e=>(i(),g(m,{key:e.label,"align-self":"start"},{default:t(()=>[a(c,{ripple:!0,class:"mx-auto home-card",outlined:"",onClick:w=>s.$router.push(e.path)},{default:t(()=>[a(p,{"two-line":""},{default:t(()=>[a(d,{variant:"plain",icon:"",ripple:!1,height:"80"},{default:t(()=>[a(u,{icon:e.icon,size:"80",style:{align:"center",padding:"10px"}},null,8,["icon"])]),_:2},1024),l("div",y,[l("h5",null,V(s.$t(e.label)),1)])]),_:2},1024)]),_:2},1032,["onClick"])]),_:2},1024))),128))]),_:1})])])]))}});export{F as default};
