import{l as d,I as m,c as v,P as f,q as l,y as _,j as e,x as a,K as o,N as s,T as g,v as y,R as V}from"./index-e9211ef1.js";import{V as n,a as T}from"./VTabs-13127e50.js";import{V as b}from"./VDivider-336c24cd.js";import"./VBtn-68784d55.js";const w=d({__name:"Settings",setup(C){const i=m(),u=v(()=>{var t,r;return(t=i.currentRoute.value.name)!=null&&t.toString().includes("player")?"players":(r=i.currentRoute.value.name)!=null&&r.toString().includes("core")?"core":"providers"});return(t,r)=>{const c=f("router-view");return l(),_("section",null,[e(T,{"hide-slider":"","model-value":u.value,"align-tabs":"end"},{default:a(()=>[e(n,{value:"providers",to:{name:"providersettings"}},{default:a(()=>[o(s(t.$t("settings.providers")),1)]),_:1}),e(n,{value:"players",to:{name:"playersettings"}},{default:a(()=>[o(s(t.$t("settings.players")),1)]),_:1}),e(n,{value:"core",to:{name:"coresettings"}},{default:a(()=>[o(s(t.$t("settings.core")),1)]),_:1})]),_:1},8,["model-value"]),e(b),e(c,{app:""},{default:a(({Component:p})=>[e(g,{name:"fade",mode:"out-in"},{default:a(()=>[(l(),y(V(p)))]),_:2},1024)]),_:1})])}}});export{w as default};
