import{c as e,q as p,v as l,V as c,z as i,x as u,Y as _,k as f}from"./index-e9211ef1.js";import{_ as v}from"./Container-349a0ac0.js";import{l as d}from"./VBtn-68784d55.js";const m={props:{variant:{type:String,default:""}},setup(t,s){const o=e(()=>({ripple:!1})),r=e(()=>({ripple:!1,icon:!0}));return{btnProps:e(()=>({...s.attrs.variant==="icon"?r.value:o.value,...s.attrs}))}}};function B(t,s,o,r,a,b){return p(),l(d,f(r.btnProps,{variant:"plain"}),c({_:2},[i(t.$slots,($,n)=>({name:n,fn:u(()=>[_(t.$slots,n)])}))]),1040)}const x=v(m,[["render",B]]);export{x as B};
